package prometheus-reporter

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Prometheus_reporter_unixSource

Report metrics for Prometheus on Unix.

See: https://prometheus.io/

Notes:

  • This module is intended to be used by applications that export Prometheus metrics. Libraries should only link against the `Prometheus` module.
  • This extends Prometheus_reporter with a process start-time metric that uses Unix.gettimeofday and a Logs reporter that counts logged messages.
Sourcemodule Logging : sig ... end

Report metrics for messages logged.